@@ -98,6 +98,9 @@ class NotebookTabWidget(Tabs, SpyderConfigurationAccessor):
         Whether to display notebooks in a dark theme. The default is False.
     untitled_num : int
         Number used in file name of newly created notebooks.
+    last_closed_files : list[str]
+        File names of notebooks that have been closed by the user, with the
+        most recently closed one listed last.
     """
 
     def __init__(self, parent, server_manager, actions=None, menu=None,
@@ -123,6 +126,7 @@ class NotebookTabWidget(Tabs, SpyderConfigurationAccessor):
         self.actions = actions
         self.dark_theme = dark_theme
         self.untitled_num = 0
+        self.last_closed_files: list[str] = []
 
         self.server_manager = server_manager
         self.server_manager.sig_server_started.connect(
@@ -163,6 +167,16 @@ class NotebookTabWidget(Tabs, SpyderConfigurationAccessor):
                 self.create_new_client(filename=filename)
         return filenames
 
+    def open_last_closed_notebook(self) -> None:
+        """
+        Reopens the notebook in the last closed tab.
+        """
+        if not self.last_closed_files:
+            return
+        else:
+            filename = self.last_closed_files.pop()
+            self.create_new_client(filename)
+
     def create_new_client(self, filename=None):
         """
         Create a new notebook or load a pre-existing one.
@@ -276,9 +290,14 @@ class NotebookTabWidget(Tabs, SpyderConfigurationAccessor):
             client.shutdown_kernel()
         client.close()
 
-        # Delete notebook file if it is in temporary directory
+        # Delete notebook file if it is in temporary directory.
+        # Otherwise, store the file name for the "Open last closed" action.
         if filename.startswith(get_temp_dir()):
             remove_file_retry_if_in_use(filename)
+        else:
+            if filename in self.last_closed_files:
+                self.last_closed_files.remove(filename)
+            self.last_closed_files.append(filename)
 
         # Note: notebook index may have changed after closing related widgets
         self.removeTab(self.indexOf(client))
@@ -362,7 +381,7 @@ class NotebookTabWidget(Tabs, SpyderConfigurationAccessor):
             # Just return True and hope for the best
             return True
 
-    def save_as(self, name=None, reopen_after_save=True):
+    def save_as(self, name=None, reopen_after_save=True, close_after_save=True):
         """
         Save current notebook under a different file name.
 
@@ -370,8 +389,8 @@ class NotebookTabWidget(Tabs, SpyderConfigurationAccessor):
         for a new file name (if `name` is not set), and return if no new name
         is given. Then, read the contents of the notebook that was just saved
         and write them under the new file name. If `reopen_after_save` is
-        True, then close the original tab and open a new tab with the
-        notebook loaded from the new file name.
+        True, then open a new tab with the notebook loaded from the new file
+        name. If `close_after_save` is True, then close the original tab.
 
         Parameters
         ----------
@@ -379,8 +398,11 @@ class NotebookTabWidget(Tabs, SpyderConfigurationAccessor):
             File name under which the notebook is to be saved. The default is
             None, meaning that the user should be asked for the file name.
         reopen_after_save : bool, optional
-            Whether to close the original tab and re-open it under the new
-            file name after saving the notebook. The default is True.
+            Whether open a tab under the new file name after saving the
+            notebook. The default is True.
+        close_after_save : bool, optional
+            Whether to close the original tab after saving the notebook. The
+            default is True.
 
         Returns
         -------
@@ -412,8 +434,9 @@ class NotebookTabWidget(Tabs, SpyderConfigurationAccessor):
                    .format(filename, str(error)))
             QMessageBox.critical(self, _("File Error"), txt)
             return original_path
-        if reopen_after_save:
+        if close_after_save:
             self.close_client(save_before_close=False)
+        if reopen_after_save:
             self.create_new_client(filename=filename)
         return filename
 
